from setuptools import setup

setup(
    name = 'htrc',
    packages = ['htrc'],
    version = '0.0.3',
    description = 'Set of Python Libraries for HTRC APIs.',
    author='Milinda Pathirage',
    author_email='milinda.pathirage@gmail.com',
    url='https://github.com/milinda/Vessel',
    classifiers=[
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Development Status :: 1 - Planning',
        'Environment :: Console',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Information Analysis'
    ]
)